@@ -43,26 +43,29 @@ fn main() {
     }
 
     let include_path;
-        let lib_result = pkg_config::Config::new()
-            .atleast_version(MINIMUM_ECCODES_VERSION)
-            .probe("eccodes");
+    let lib_result = pkg_config::Config::new()
+        .atleast_version(MINIMUM_ECCODES_VERSION)
+        .probe("eccodes");
 
-        match lib_result {
-            Ok(pk) => {
-                eprintln!(
-                    "Found installed ecCodes library to link at: {:?}",
-                    pk.link_paths[0]
-                );
-                println!("cargo:rustc-link-search=native={:?}", pk.link_paths[0]);
-                println!("cargo:rustc-link-lib=eccodes");
-                include_path = pk.include_paths[0].clone();
-            }
-            Err(err) => {
-                panic!("Cannot find existing ecCodes library. 
-                Please check the README for information how to correctly install ecCodes.
-                Additional error information: {}", err);
-            }
+    match lib_result {
+        Ok(pk) => {
+            eprintln!(
+                "Found installed ecCodes library to link at: {:?}",
+                pk.link_paths[0]
+            );
+            println!("cargo:rustc-link-search={:?}", pk.link_paths[0]);
+            println!("cargo:rustc-link-lib=eccodes");
+            include_path = pk.include_paths[0].clone();
         }
+        Err(err) => {
+            panic!(
+                "Cannot find existing ecCodes library. 
+                Please check the README for information how to correctly install ecCodes.
+                Additional error information: {}",
+                err
+            );
+        }
+    }
 
     //bindgen magic to avoid duplicate math.h type definitions
     let macros = Arc::new(RwLock::new(HashSet::new()));
